##  1. Create a New Fact Sheet Type
i. Navigate to Administration > Meta Model Configuration, and click on New Fact Sheet type.
![Meta Model Configuration - Create a New Fact Sheet type](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274eb40a7a441014b755d69e31ec22c9_LowRes.png)
Meta Model Configuration - Create a New Fact Sheet type
ii. Fill in the Fact Sheet details using the provided values below:
Fields | Values
---|---
Internal Name: | Platform
Singular: | Platform
Plural: | Platforms
Description: | Which Platforms are supporting the business?


iii. Click Create,
A new Fact Sheet type named Platform is created.
